mailr9266 - /1.3/test_suite/system_tests/diffusion_tensor.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on July 22, 2009 - 01:11:
Author: bugman
Date: Wed Jul 22 01:10:56 2009
New Revision: 9266

URL: http://svn.gna.org/viewcvs/relax?rev=9266&view=rev
Log:
Extended the test_copy() system test to properly check if a copy is made, 
rather than link.


Modified:
    1.3/test_suite/system_tests/diffusion_tensor.py

Modified: 1.3/test_suite/system_tests/diffusion_tensor.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/system_tests/diffusion_tensor.py?rev=9266&r1=9265&r2=9266&view=diff
==============================================================================
--- 1.3/test_suite/system_tests/diffusion_tensor.py (original)
+++ 1.3/test_suite/system_tests/diffusion_tensor.py Wed Jul 22 01:10:56 2009
@@ -65,7 +65,7 @@
         self.relax.interpreter._Diffusion_tensor.init((9e-8, 5e6, 0.3, 
60+360, 290, 100), fixed=False)
         self.tmpfile_ellipsoid = mktemp()
 
         # Some fake MC simulations (for the spheroid).
         self.relax.interpreter._Pipe.switch('sphere')
         cdp = get_pipe()
         cdp.diff_tensor.tm_err = 10e-11
@@ -158,10 +158,19 @@
         self.relax.interpreter._Pipe.create('spheroid2', 'mf')
         self.relax.interpreter._Pipe.create('ellipsoid2', 'mf')
 
-        # Delete the data.
+        # Copy the data.
         self.relax.interpreter._Diffusion_tensor.copy('sphere', 'sphere2')
         self.relax.interpreter._Diffusion_tensor.copy('spheroid', 
'spheroid2')
         self.relax.interpreter._Diffusion_tensor.copy('ellipsoid', 
'ellipsoid2')
+
+        # Get the data pipes.
+        sphere_pipe = get_pipe('sphere')
+        sphere2_pipe = get_pipe('sphere2')
+
+        # Check that this is indeed a copy.
+        self.assertEqual(sphere2_pipe.diff_tensor.tm_sim[1], 9.02e-8)
+        sphere_pipe.diff_tensor.tm_sim[4] = 8.88e-8
+        self.assertEqual(sphere2_pipe.diff_tensor.tm_sim[1], 9.02e-8)
 
 
     def test_delete(self):
@@ -65,7 +65,7 @@
         self.tmpfile_ellipsoid = mktemp()
 
-        # Some fake MC simulations (for the spheroid).
+        # Some fake MC simulations (for the sphere).
         self.relax.interpreter._Pipe.switch('sphere')
         cdp = get_pipe()




Related Messages


Powered by MHonArc, Updated Wed Jul 22 01:40:02 2009